%---------------------------------------------------------------------------
% Identification part
%---------------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{polytexbeta}[2000/05/29]

\def\fileversion{2.0}

%%% Commande de cration d'un nouveau triplet \ifcmd \cmdTrue \cmdFalse.
%%% Les dfinitions sont maintenant globales.
%%%
%%% \poly@newif{cmd}{True} ou \poly@newif{cmd}{False} permet d'initialiser
%%% le booleen \cmd  la valeur correspondante.

\def\poly@newif#1#2{%
   \expandafter\newif\csname if#1\endcsname%
   \expandafter\def\csname #1True\endcsname{\global\csname#1true\endcsname}%
   \expandafter\def\csname #1False\endcsname{\global\csname#1false\endcsname}%
   \csname #1#2\endcsname%
}

\RequirePackage{ifthen}
\RequirePackage{version}

\poly@newif{macintosh}{False}

%---------------------------------------------------------------------------
% initial code
%---------------------------------------------------------------------------

\poly@newif{transparent}{False}
\poly@newif{polycopie}{False}
\poly@newif{propre}{False}
\poly@newif{intermediaire}{True}

\DeclareOption{10pt}{%
   \PassOptionsToClass{10pt}{book}
}

\DeclareOption{11pt}{%
   \PassOptionsToClass{11pt}{book}
}

\DeclareOption{12pt}{%
   \PassOptionsToClass{12pt}{book}
}

\DeclareOption{impression}{%
   \PassOptionsToClass{twoside,a4paper}{book}
   \PassOptionsToPackage{impression}{polycop}
   \PassOptionsToPackage{linkcolor=black}{hyperref}
}

\DeclareOption{ecran}{%
   \PassOptionsToClass{oneside,a4paper}{book}
   \PassOptionsToPackage{ecran}{polycop}
   \PassOptionsToPackage{linkcolor=blue}{hyperref}
}

\DeclareOption{intermediaire}{%
   \intermediaireTrue%
}

\DeclareOption{final}{%
   \intermediaireFalse%
}

\DeclareOption{polycopie}{%
   \polycopieTrue%
   \transparentFalse%
}

\DeclareOption{transparent}{%
   \polycopieFalse%
   \transparentTrue%
}

\DeclareOption{propre}{%
   \propreTrue%
}

\DeclareOption{sale}{%
   \propreFalse%
}

\DeclareOption*{%
  \PassOptionsToPackage{\CurrentOption}{polycop}%
}

%---------------------------------------------------------------------------
% Execution of options
%---------------------------------------------------------------------------

\ExecuteOptions{ecran,final,polycopie,sale,10pt}

\ProcessOptions

%---------------------------------------------------------------------------
% Choix de l'encodage des fonts : T1 au lieu de OT1 pour eviter de nombreux
% problemes lies au caracteres accentues.
%---------------------------------------------------------------------------
%---------------------------------------------------------------------------
% Choix de l'encodage des caracteres du fichier source 
% suivant la plate-forme.
%
% Pour Unix et DOS, l'encodage des
% caracteres accentues est pris en compte automatiquement par le codage T1.
% Cependant, pour le Macintosh, le codage etant different, on doit utiliser 
% en plus  \RequirePackage[mac]{inputenc}.
%---------------------------------------------------------------------------

\ifmacintosh
   \RequirePackage[T1]{fontenc}
   \RequirePackage[mac]{inputenc}
   \ifpropre
      \def\prefixe{:poly:}
   \else
      \def\prefixe{:}
   \fi
   \def\separateur{:}
\else
   \RequirePackage[T1]{fontenc}
   \ifpropre
       \def\prefixe{poly/}
   \else
       \def\prefixe{./}
   \fi
   \def\separateur{/}
\fi

\xdef\jobslides{\jobname -slides}
\xdef\jobpoly{\jobname -poly}

\let\oldjobname=\jobname

\iftransparent
   \xdef\jobname{\prefixe\oldjobname -slides}
   \typeout{jobname = \jobname
\else
   \xdef\jobname{\prefixe\oldjobname -poly}
   \typeout{jobname = \jobname}%
\fi

%---------------------------------------------------------------------------
% Class loading
%---------------------------------------------------------------------------

\iftransparent
\else
   \LoadClass{book}
   \ifx\pdfoutput\undefined        % on teste si on est dans latex
     \RequirePackage[]{hyperref}
     \RequirePackage[xdvi]{graphicx}
     \RequirePackage[xdvi]{color}
     \RequirePackage[xdvi]{epsfig}
     \DeclareGraphicsExtensions{.ps,.eps,.pstex}
   \else                           % sinon on est dans pdflatex
     \RequirePackage[pdftex,colorlinks,hyperindex]{hyperref}
     \RequirePackage[pdftex]{graphicx}
     \RequirePackage[pdftex]{color}
     \RequirePackage[pdftex]{epsfig}
   \fi
%
   \RequirePackage{fancyhdr}
   \RequirePackage{multind}
   \RequirePackage[frenchb]{babel}
   \RequirePackage{ae}
   \AtBeginDocument{\RequirePackage{mathfont}}
   \RequirePackage{polycop}
\fi

\ifmacintosh
   \graphicspath{{:figures:}}
\else
   \graphicspath{{figures/}}
\fi

\endinput
